@@ -1,29 +1,44 @@
 # -*- coding: utf-8 -*-
+from typing import List
 
 from qqbot.model.member import User, Member
 
 
 class Message:
     def __init__(self, data=None):
-        self.id = ""
-        self.channel_id = ""
-        self.guild_id = ""
-        self.content = ""
-        self.timestamp = ""
-        self.edited_timestamp = ""
-        self.author = User()
-        self.attachments = [MessageAttachment()]
-        self.embeds = [MessageEmbed()]
-        self.mentions = [User()]
-        self.member = Member()
-        self.ark = MessageArk()
+        self.id: str = ""
+        self.channel_id: str = ""
+        self.guild_id: str = ""
+        self.content: str = ""
+        self.timestamp: str = ""
+        self.edited_timestamp: str = ""
+        self.author: User = User()
+        self.attachments: List[MessageAttachment] = [MessageAttachment()]
+        self.embeds: List[MessageEmbed] = [MessageEmbed()]
+        self.mentions: List[User] = [User()]
+        self.member: Member = Member()
+        self.ark: MessageArk = MessageArk()
         if data:
             self.__dict__ = data
 
 
+class TypesEnum:
+    around = "around"
+    before = "before"
+    after = "after"
+    latest = ""
+
+
+class MessagesPager:
+    def __init__(self, type: TypesEnum, id: str, limit: str):
+        self.type = type
+        self.id = id
+        self.limit = limit
+
+
 class MessageAttachment:
     def __init__(self, data=None):
-        self.url = ""
+        self.url: str = ""
         if data:
             self.__dict__ = data
 
@@ -31,13 +46,13 @@ class MessageAttachment:
 class MessageEmbed:
     def __init__(self, data=None):
         # 标题
-        self.title = ""
+        self.title: str = ""
         # 消息弹窗内容
-        self.prompt = ""
+        self.prompt: str = ""
         # 缩略图
-        self.thumbnail = MessageEmbedThumbnail()
+        self.thumbnail: MessageEmbedThumbnail = MessageEmbedThumbnail()
         # 消息创建时间
-        self.fields = [MessageEmbedField()]
+        self.fields: List[MessageEmbedField] = [MessageEmbedField()]
         if data:
             self.__dict__ = data
 
@@ -45,15 +60,15 @@ class MessageEmbed:
 class MessageEmbedThumbnail:
     def __init__(self, data=None):
         # 图片地址
-        self.url = ""
+        self.url: str = ""
         if data is not None:
             self.__dict__ = data
 
 
 class MessageEmbedField:
     def __init__(self, data=None):
-        self.key = ""
-        self.value = ""
+        self.key: str = ""
+        self.value: str = ""
         if data:
             self.__dict__ = data
 
@@ -61,31 +76,31 @@ class MessageEmbedField:
 class MessageArk:
     def __init__(self, data=None):
         self.template_id = 0
-        self.kv = [MessageArkKv()]
+        self.kv: List[MessageArkKv] = [MessageArkKv()]
         if data:
             self.__dict__ = data
 
 
 class MessageArkKv:
     def __init__(self, data=None):
-        self.key = ""
-        self.value = ""
-        self.obj = [MessageArkObj()]
+        self.key: str = ""
+        self.value: str = ""
+        self.obj: List[MessageArkObj] = [MessageArkObj()]
         if data:
             self.__dict__ = data
 
 
 class MessageArkObj:
     def __init__(self, data=None):
-        self.obj_kv = [MessageArkObjKv()]
+        self.obj_kv: List[MessageArkObjKv] = [MessageArkObjKv()]
         if data:
             self.__dict__ = data
 
 
 class MessageArkObjKv:
     def __init__(self, data=None):
-        self.key = ""
-        self.value = ""
+        self.key: str = ""
+        self.value: str = ""
         if data:
             self.__dict__ = data
 
@@ -93,11 +108,11 @@ class MessageArkObjKv:
 class MessageSendRequest:
     def __init__(
         self,
-        content,
-        msg_id=None,
+        content: str,
+        msg_id: str = None,
         embed: MessageEmbed = None,
         ark: MessageArk = None,
-        image="",
+        image: str = "",
     ):
         """
 
@@ -117,15 +132,15 @@ class MessageSendRequest:
 
 class DirectMessageGuild:
     def __init__(self, data=None):
-        self.guild_id = ""
-        self.channel_id = ""
-        self.creat_time = ""
+        self.guild_id: str = ""
+        self.channel_id: str = ""
+        self.creat_time: str = ""
         if data is not None:
             self.__dict__ = data
 
 
 class CreateDirectMessageRequest:
-    def __init__(self, source_guild_id, user_id):
+    def __init__(self, source_guild_id: str, user_id: str):
         """
         :param source_guild_id: 创建的私信频道ID
         :param user_id: 私信接收人用户ID
